/// Help content for PrayerTracker
module PrayerTracker.Views.Help

open System.IO
open Giraffe.ViewEngine

/// The help index page
let index () =
    let s   = I18N.localizer.Force()
    let l   = I18N.forView "Help/Index"
    use sw  = new StringWriter()
    let raw = rawLocText sw
    [ p [] [
          raw l["Throughout PrayerTracker, you'll see an icon (a question mark in a circle) next to the title on each page."]; space
          raw l["Clicking this will open a new, small window with directions on using that page."]; space
          raw l["If you are looking for a quick overview of PrayerTracker, start with the “Add / Edit a Request” and “Change Preferences” entries."] ]
      hr []
      p [ _class "pt-center-text" ] [ strong [] [ locStr s["Help Topics"] ] ]
      p [] [ a [ _href "/help/small-group/preferences"  ] [ locStr s["Change Preferences"]     ] ]
      p [] [ a [ _href "/help/small-group/announcement" ] [ locStr s["Send Announcement"]      ] ]
      p [] [ a [ _href "/help/small-group/members"      ] [ locStr s["Maintain Group Members"] ] ]
      p [] [ a [ _href "/help/requests/edit"            ] [ locStr s["Add / Edit a Request"]   ] ]
      p [] [ a [ _href "/help/requests/maintain"        ] [ locStr s["Maintain Requests"]      ] ]
      p [] [ a [ _href "/help/requests/view"            ] [ locStr s["View Request List"]      ] ]
      p [] [ a [ _href "/help/user/log-on"              ] [ locStr s["Log On"]                 ] ]
      p [] [ a [ _href "/help/user/password"            ] [ locStr s["Change Your Password"]   ] ] ]


/// Help for prayer requests
module Requests =
    
    /// Add / Edit a Request
    let edit () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/Requests/Edit"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [ raw l["This page allows you to enter or update a new prayer request."] ]
          h2 [] [ locStr s["Request Type"] ]
          p [] [
              raw l["There are 5 request types in PrayerTracker."]; space
              raw l["“Current Requests” are your regular requests that people may have regarding things happening over the next week or so."]; space
              raw l["“Long-Term Requests” are requests that may occur repeatedly or continue indefinitely."]; space
              raw l["“Praise Reports” are like “Current Requests”, but they are answers to prayer to share with your group."]; space
              raw l["“Expecting” is for those who are pregnant."]; space
              raw l["“Announcements” are like “Current Requests”, but instead of a request, they are simply passing information along about something coming up."] ]
          p [] [
              raw l["The order above is the order in which the request types appear on the list."]; space
              raw l["“Long-Term Requests” and “Expecting” are not subject to the automatic expiration (set on the “Change Preferences” page) that the other requests are."] ]
          h2 [] [ locStr s["Date"] ]
          p [] [
              raw l["For new requests, this is a box with a calendar date picker."]; space
              raw l["Click or tab into the box to display the calendar, which will be preselected to today's date."]; space
              raw l["For existing requests, there will be a check box labeled “Check to not update the date”."]; space
              raw l["This can be used if you are correcting spelling or punctuation, and do not have an actual update to make to the request."]
          ]
          h2 [] [ locStr s["Requestor / Subject"] ]
          p [] [
              raw l["For requests or praises, this field is for the name of the person who made the request or offered the praise report."]; space
              raw l["For announcements, this should contain the subject of the announcement."]; space
              raw l["For all types, it is optional; I used to have an announcement with no subject that ran every week, telling where to send requests and updates."] ]
          h2 [] [ locStr s["Expiration"] ]
          p [] [
              raw l["“Expire Normally” means that the request is subject to the expiration days in the group preferences."]; space
              raw l["“Request Never Expires” can be used to make a request never expire (note that this is redundant for “Long-Term Requests” and “Expecting”)."]; space
              raw l["If you are editing an existing request, a third option appears."]; space
              raw l["“Expire Immediately” will make the request expire when it is saved."]; space
              raw l["Apart from the icons on the request maintenance page, this is the only way to expire “Long-Term Requests” and “Expecting” requests, but it can be used for any request type."] ]
          h2 [] [ locStr s["Request"] ]
          p [] [
              raw l["This is the text of the request."]; space
              raw l["The editor provides many formatting capabilities, including “Spell Check as you Type” (enabled by default), “Paste from Word”, and “Paste Plain”, as well as “Source” view, if you want to edit the HTML yourself."]; space
              raw l["It also supports undo and redo, and the editor supports full-screen mode. Hover over each icon to see what each button does."] ] ]
    
    /// Maintain Requests
    let maintain () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/Requests/Maintain"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [
              raw l["From this page, you can add, edit, and delete your current requests."]; space
              raw l["You can also restore requests that may have expired, but should be made active once again."] ]
          h2 [] [ locStr s["Add a New Request"] ]
          p [] [
              raw l["To add a request, click the icon or text in the center of the page, below the title and above the list of requests for your group."] ]
          h2 [] [ locStr s["Search Requests"] ]
          p [] [
              raw l["If you are looking for a particular requests, enter some text in the search box and click “Search”."]; space
              raw l["PrayerTracker will search the Requestor/Subject and Request Text fields (case-insensitively) of both active and inactive requests."]; space
              raw l["The results will be displayed in the same format as the original Maintain Requests page, so the buttons described below will work the same for those requests as well."]; space
              raw l["They will also be displayed in pages, if there are a lot of results; the number per page is configurable by small group."] ]
          h2 [] [ locStr s["Edit Request"] ]
          p [] [
              raw l["To edit a request, click the pencil icon; it's the first icon under the “Actions” column heading."] ]
          h2 [] [ locStr s["Expire a Request"] ]
          p [] [
              raw l["For active requests, the second icon is an eye with a slash through it; clicking this icon will expire the request immediately."]; space
              raw l["This is equivalent to editing the request, selecting “Expire Immediately”, and saving it."] ]
          h2 [] [ locStr s["Restore an Inactive Request"] ]
          p [] [
              raw l["When the page is first displayed, it does not display inactive requests."]; space
              raw l["However, clicking the link at the bottom of the page will refresh the page with the inactive requests shown."]; space
              raw l["The middle icon will look like an eye; clicking it will restore the request as an active request."]; space
              raw l["The last updated date will be current, and the request is set to expire normally."] ]
          h2 [] [ locStr s["Delete a Request"] ]
          p [] [
              raw l["Deleting a request is contrary to the intent of PrayerTracker, as you can retrieve requests that have expired."]; space
              raw l["However, if there is a request that needs to be deleted, clicking the trash can icon in the “Actions” column will allow you to do it."]; space
              raw l["Use this option carefully, as these deletions cannot be undone; once a request is deleted, it is gone for good."] ] ]
    
    let view () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/Requests/View"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [
              raw l["From this page, you can view the request list (for today or for the next Sunday), view a printable version of the list, and e-mail the list to the members of your group."]; space
              raw l["(NOTE: If you are logged in as a group member, the only option you will see is to view a printable list.)"] ]
          h2 [] [ locStr s["List for Next Sunday"] ]
          p [] [
              raw l["This will modify the date for the list, so it will look like it is currently next Sunday."]; space
              raw l["This can be used, for example, to see what requests will expire, or allow you to print a list with Sunday's date on Saturday evening."]; space
              raw l["Note that this link does not appear if it is Sunday."] ]
          h2 [] [ locStr s["View Printable"] ]
          p [] [
              raw l["Clicking this link will display the list in a format that is suitable for printing; it does not have the normal PrayerTracker header across the top."]; space
              raw l["Once you have clicked the link, you can print it using your browser's standard “Print” functionality."] ]
          h2 [] [ locStr s["Send via E-mail"] ]
          p [] [
              raw l["Clicking this link will send the list you are currently viewing to your group members."]; space
              raw l["The page will remind you that you are about to do that, and ask for your confirmation."]; space
              raw l["If you proceed, you will see a page that shows to whom the list was sent, and what the list looked like."]; space
              raw l["You may safely use your browser's “Back” button to navigate away from the page."] ] ]
        